@@ -21,7 +21,7 @@ SHARE_PERC_MIN = 0.1
 class ReportDataException(Exception):
     pass
 
-def run_summary_cat_report(output_dir, df):
+def run_summary_cat_report(output_dir, df, retailer=False):
 
     df["quarter_end"] = pd.to_datetime(df["quarter_end"])
     df = df[df["valid_quarter"]]
@@ -34,10 +34,9 @@ def run_summary_cat_report(output_dir, df):
         sdf = df[df["symbol"] == symbol]
         sdf = sdf.dropna(how="all", axis=1)
         share_percs = get_share_percs(sdf)
-        sdf = sdf[[c for c in sdf.columns if c in ["quarter_end",REVENUE_REPORT,REVENUE_EST,PROFIT_REPORT,PROFIT_EST,EPS_REPORT,EPS_EST,NPD_TOTAL_DOLLARS]] + [c for c in sdf.columns if (c not in NON_SALES_COLS and share_percs[c] > SHARE_PERC_MIN)]]
+        sdf = sdf[[c for c in sdf.columns if c in ["quarter_end",REVENUE_REPORT,REVENUE_EST,PROFIT_REPORT,PROFIT_EST,EPS_REPORT,EPS_EST,NPD_TOTAL_DOLLARS]] + [c for c in sdf.columns if (c not in NON_SALES_COLS and share_percs[c] > SHARE_PERC_MIN) or (c not in NON_SALES_COLS and retailer)]]
         sdf_yy = get_yy_df(sdf)
 
-        print(symbol)
         #revenue correlations
         best_rev_cat, rev_cat_corr, rev_total_corr, rev_est_corr = get_ticker_correlations(sdf_yy, REVENUE_REPORT, REVENUE_EST)
         if np.nan not in [best_rev_cat, rev_cat_corr]:
@@ -111,7 +110,7 @@ def get_share_percs(sdf):
     return share_percs
 
 def get_ticker_correlations(sdf, measure, measure_est, min_periods=4):
-
+    print(sdf)
     if measure not in sdf.columns or (measure_est != None and measure_est not in sdf.columns):
         return np.nan, np.nan, np.nan, np.nan
     corr_df = sdf.corr(min_periods=min_periods)
@@ -127,7 +126,7 @@ def get_ticker_correlations(sdf, measure, measure_est, min_periods=4):
     return best_cat, best_cat_corr, total_dollars_corr, est_corr
 
 
-def run_cat_report(output_dir, ticker, df):
+def run_cat_report(output_dir, ticker, df, retailer=False):
 
     df["quarter_end"] = pd.to_datetime(df["quarter_end"])
     df = df[df["valid_quarter"]]
@@ -138,7 +137,7 @@ def run_cat_report(output_dir, ticker, df):
     sdf = df[df["symbol"] == ticker]
     sdf = sdf.dropna(how="all", axis=1)
     share_percs = get_share_percs(sdf)
-    sdf = sdf[[c for c in sdf.columns if c in ["quarter_end",REVENUE_REPORT,REVENUE_EST,PROFIT_REPORT,PROFIT_EST,EPS_REPORT,EPS_EST,NPD_TOTAL_DOLLARS]] + [c for c in sdf.columns if (c not in NON_SALES_COLS and share_percs[c] > SHARE_PERC_MIN)]]
+    sdf = sdf[[c for c in sdf.columns if c in ["quarter_end",REVENUE_REPORT,REVENUE_EST,PROFIT_REPORT,PROFIT_EST,EPS_REPORT,EPS_EST,NPD_TOTAL_DOLLARS]] + [c for c in sdf.columns if (c not in NON_SALES_COLS and share_percs[c] > SHARE_PERC_MIN) or (c not in NON_SALES_COLS and retailer)]]
     sdf_yy = get_yy_df(sdf)
 
     sdf = sdf.set_index("quarter_end").reset_index().sort_values("quarter_end")
